@@ -20,6 +20,6 @@ sub handle {
 	die UvT::Kiki::ACL::Document(req => $req)->new->response
  		unless $req->authorized;
 	my $res = super($req, @_);
-	$res->setcookie($req->session) unless $req->cur_session;
+	$res->setcookie(session => $req->session) unless $req->cur_session;
 	return $res;
 }
